@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001001';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001002';
 #pod =encoding UTF-8
 #pod  
 #pod =head1 SYNOPSIS
@@ -19,6 +19,8 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '1.001001';
 #pod 	# Files included
 #pod 	#
 #pod 	[GatherDir]
+#pod 	prune_directory=^extlib$
+#pod 	
 #pod 	[PruneCruft]
 #pod 	[ExecDir]
 #pod 	dir = bin
@@ -141,6 +143,7 @@ sub configure {
 		#
 		['GatherDir' => {                 # skip files on top level
 			exclude_match => \@exclude_matches,
+			prune_directory => ['^extlib$'],
 		}],
 		'PruneCruft',                     # prune stuff you probably don't want
 		
@@ -189,8 +192,8 @@ sub configure {
 		'Prereqs::AuthorDeps',            # "adds Dist::Zilla and the result of "dzil
 		                                  # authordeps" to the 'develop' phase prerequisite list"
 		'PrereqsClean',                   # "Cleans up mess from other Prereq modules"
-		['Prereqs', 'MAXHQ', {            # special prerequisites (name MAXHQ 
-			'-phase' => 'runtime',        # disambiguates the Prereqs plugin in
+		['Prereqs' => 'MAXHQ-DEV', {      # special prerequisites (name MAXHQ-DEV 
+			'-phase' => 'develop',        # disambiguates the Prereqs plugin in
 			'-relationship' => 'requires',# case it's also specified in users' dist.ini)
 			'Pod::Elemental::Transformer::List' => 0, # not automatically installed with Dist::Zilla
 			'Pod::Coverage::TrustPod' => 0,           # not automatically installed with Dist::Zilla
@@ -245,7 +248,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 1.001001
+version 1.001002
 
 =head1 SYNOPSIS
 
@@ -262,6 +265,8 @@ Currently this plugin bundle is equivalent to:
 	# Files included
 	#
 	[GatherDir]
+	prune_directory=^extlib$
+	
 	[PruneCruft]
 	[ExecDir]
 	dir = bin
